# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowVersionConfigMetaData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowVersionConfigMetaData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version_specific_comment': 'str',
            'flow_definition_uri': 'str',
            'created_by_user': 'User',
            'created_date': 'datetime',
            'self_uri': 'str',
            'version': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version_specific_comment': 'versionSpecificComment',
            'flow_definition_uri': 'flowDefinitionUri',
            'created_by_user': 'createdByUser',
            'created_date': 'createdDate',
            'self_uri': 'selfUri',
            'version': 'version'
        }

        self._id = None
        self._name = None
        self._version_specific_comment = None
        self._flow_definition_uri = None
        self._created_by_user = None
        self._created_date = None
        self._self_uri = None
        self._version = None

    @property
    def id(self):
        """
        Gets the id of this FlowVersionConfigMetaData.
        The globally unique identifier for the object.

        :return: The id of this FlowVersionConfigMetaData.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FlowVersionConfigMetaData.
        The globally unique identifier for the object.

        :param id: The id of this FlowVersionConfigMetaData.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FlowVersionConfigMetaData.


        :return: The name of this FlowVersionConfigMetaData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FlowVersionConfigMetaData.


        :param name: The name of this FlowVersionConfigMetaData.
        :type: str
        """
        self._name = name

    @property
    def version_specific_comment(self):
        """
        Gets the version_specific_comment of this FlowVersionConfigMetaData.
        Checkin comment for this specific flow version.

        :return: The version_specific_comment of this FlowVersionConfigMetaData.
        :rtype: str
        """
        return self._version_specific_comment

    @version_specific_comment.setter
    def version_specific_comment(self, version_specific_comment):
        """
        Sets the version_specific_comment of this FlowVersionConfigMetaData.
        Checkin comment for this specific flow version.

        :param version_specific_comment: The version_specific_comment of this FlowVersionConfigMetaData.
        :type: str
        """
        self._version_specific_comment = version_specific_comment

    @property
    def flow_definition_uri(self):
        """
        Gets the flow_definition_uri of this FlowVersionConfigMetaData.
        Uri location for the flow definition contents.

        :return: The flow_definition_uri of this FlowVersionConfigMetaData.
        :rtype: str
        """
        return self._flow_definition_uri

    @flow_definition_uri.setter
    def flow_definition_uri(self, flow_definition_uri):
        """
        Sets the flow_definition_uri of this FlowVersionConfigMetaData.
        Uri location for the flow definition contents.

        :param flow_definition_uri: The flow_definition_uri of this FlowVersionConfigMetaData.
        :type: str
        """
        self._flow_definition_uri = flow_definition_uri

    @property
    def created_by_user(self):
        """
        Gets the created_by_user of this FlowVersionConfigMetaData.
        If known, the user who created this flow version.

        :return: The created_by_user of this FlowVersionConfigMetaData.
        :rtype: User
        """
        return self._created_by_user

    @created_by_user.setter
    def created_by_user(self, created_by_user):
        """
        Sets the created_by_user of this FlowVersionConfigMetaData.
        If known, the user who created this flow version.

        :param created_by_user: The created_by_user of this FlowVersionConfigMetaData.
        :type: User
        """
        self._created_by_user = created_by_user

    @property
    def created_date(self):
        """
        Gets the created_date of this FlowVersionConfigMetaData.
        The date and time that the version was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this FlowVersionConfigMetaData.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this FlowVersionConfigMetaData.
        The date and time that the version was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this FlowVersionConfigMetaData.
        :type: datetime
        """
        self._created_date = created_date

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FlowVersionConfigMetaData.
        The URI for this object

        :return: The self_uri of this FlowVersionConfigMetaData.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FlowVersionConfigMetaData.
        The URI for this object

        :param self_uri: The self_uri of this FlowVersionConfigMetaData.
        :type: str
        """
        self._self_uri = self_uri

    @property
    def version(self):
        """
        Gets the version of this FlowVersionConfigMetaData.
        Version of this flow config.

        :return: The version of this FlowVersionConfigMetaData.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this FlowVersionConfigMetaData.
        Version of this flow config.

        :param version: The version of this FlowVersionConfigMetaData.
        :type: str
        """
        self._version = version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowReportResultItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowReportResultItem - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'flow_exec_id': 'FlowExecId',
            'flow_config_id': 'FlowConfigId',
            'flow_instance_name': 'str',
            'associated_document': 'AssociatedDocument',
            'flow_status': 'str',
            'current_state': 'str',
            'start_date_time': 'datetime',
            'end_date_time': 'datetime',
            'work_item_user_assignees': 'list[User]',
            'completed_user': 'User',
            'completion_reason': 'str',
            'flow_error_info': 'ErrorBody'
        }

        self.attribute_map = {
            'flow_exec_id': 'flowExecId',
            'flow_config_id': 'flowConfigId',
            'flow_instance_name': 'flowInstanceName',
            'associated_document': 'associatedDocument',
            'flow_status': 'flowStatus',
            'current_state': 'currentState',
            'start_date_time': 'startDateTime',
            'end_date_time': 'endDateTime',
            'work_item_user_assignees': 'workItemUserAssignees',
            'completed_user': 'completedUser',
            'completion_reason': 'completionReason',
            'flow_error_info': 'flowErrorInfo'
        }

        self._flow_exec_id = None
        self._flow_config_id = None
        self._flow_instance_name = None
        self._associated_document = None
        self._flow_status = None
        self._current_state = None
        self._start_date_time = None
        self._end_date_time = None
        self._work_item_user_assignees = None
        self._completed_user = None
        self._completion_reason = None
        self._flow_error_info = None

    @property
    def flow_exec_id(self):
        """
        Gets the flow_exec_id of this FlowReportResultItem.
        The flow instance ID for this process

        :return: The flow_exec_id of this FlowReportResultItem.
        :rtype: FlowExecId
        """
        return self._flow_exec_id

    @flow_exec_id.setter
    def flow_exec_id(self, flow_exec_id):
        """
        Sets the flow_exec_id of this FlowReportResultItem.
        The flow instance ID for this process

        :param flow_exec_id: The flow_exec_id of this FlowReportResultItem.
        :type: FlowExecId
        """
        self._flow_exec_id = flow_exec_id

    @property
    def flow_config_id(self):
        """
        Gets the flow_config_id of this FlowReportResultItem.
        The flow config ID that this workitem was created from.

        :return: The flow_config_id of this FlowReportResultItem.
        :rtype: FlowConfigId
        """
        return self._flow_config_id

    @flow_config_id.setter
    def flow_config_id(self, flow_config_id):
        """
        Sets the flow_config_id of this FlowReportResultItem.
        The flow config ID that this workitem was created from.

        :param flow_config_id: The flow_config_id of this FlowReportResultItem.
        :type: FlowConfigId
        """
        self._flow_config_id = flow_config_id

    @property
    def flow_instance_name(self):
        """
        Gets the flow_instance_name of this FlowReportResultItem.
        The instance name for this flow in relation to its primary document.  If the flow is not a document-centric type, this value will be empty.

        :return: The flow_instance_name of this FlowReportResultItem.
        :rtype: str
        """
        return self._flow_instance_name

    @flow_instance_name.setter
    def flow_instance_name(self, flow_instance_name):
        """
        Sets the flow_instance_name of this FlowReportResultItem.
        The instance name for this flow in relation to its primary document.  If the flow is not a document-centric type, this value will be empty.

        :param flow_instance_name: The flow_instance_name of this FlowReportResultItem.
        :type: str
        """
        self._flow_instance_name = flow_instance_name

    @property
    def associated_document(self):
        """
        Gets the associated_document of this FlowReportResultItem.
        the document for this flow (if this flow was launched via a document)

        :return: The associated_document of this FlowReportResultItem.
        :rtype: AssociatedDocument
        """
        return self._associated_document

    @associated_document.setter
    def associated_document(self, associated_document):
        """
        Sets the associated_document of this FlowReportResultItem.
        the document for this flow (if this flow was launched via a document)

        :param associated_document: The associated_document of this FlowReportResultItem.
        :type: AssociatedDocument
        """
        self._associated_document = associated_document

    @property
    def flow_status(self):
        """
        Gets the flow_status of this FlowReportResultItem.
        The flow's running status, which indicates whether the flow is running normally or in error, etc;

        :return: The flow_status of this FlowReportResultItem.
        :rtype: str
        """
        return self._flow_status

    @flow_status.setter
    def flow_status(self, flow_status):
        """
        Sets the flow_status of this FlowReportResultItem.
        The flow's running status, which indicates whether the flow is running normally or in error, etc;

        :param flow_status: The flow_status of this FlowReportResultItem.
        :type: str
        """
        allowed_values = ["UNKNOWN", "RUNNING", "ERROR", "TERMINATED", "COMPLETED"]
        if flow_status not in allowed_values:
            raise ValueError(
                "Invalid value for `flow_status`, must be one of {0}"
                .format(allowed_values)
            )
        self._flow_status = flow_status

    @property
    def current_state(self):
        """
        Gets the current_state of this FlowReportResultItem.
        The current state of the flow (EG what action is being processed)

        :return: The current_state of this FlowReportResultItem.
        :rtype: str
        """
        return self._current_state

    @current_state.setter
    def current_state(self, current_state):
        """
        Sets the current_state of this FlowReportResultItem.
        The current state of the flow (EG what action is being processed)

        :param current_state: The current_state of this FlowReportResultItem.
        :type: str
        """
        self._current_state = current_state

    @property
    def start_date_time(self):
        """
        Gets the start_date_time of this FlowReportResultItem.
        The time the flow was started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_date_time of this FlowReportResultItem.
        :rtype: datetime
        """
        return self._start_date_time

    @start_date_time.setter
    def start_date_time(self, start_date_time):
        """
        Sets the start_date_time of this FlowReportResultItem.
        The time the flow was started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_date_time: The start_date_time of this FlowReportResultItem.
        :type: datetime
        """
        self._start_date_time = start_date_time

    @property
    def end_date_time(self):
        """
        Gets the end_date_time of this FlowReportResultItem.
        The time the flow ended. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The end_date_time of this FlowReportResultItem.
        :rtype: datetime
        """
        return self._end_date_time

    @end_date_time.setter
    def end_date_time(self, end_date_time):
        """
        Sets the end_date_time of this FlowReportResultItem.
        The time the flow ended. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param end_date_time: The end_date_time of this FlowReportResultItem.
        :type: datetime
        """
        self._end_date_time = end_date_time

    @property
    def work_item_user_assignees(self):
        """
        Gets the work_item_user_assignees of this FlowReportResultItem.
        List of users currently assigned to a workItem

        :return: The work_item_user_assignees of this FlowReportResultItem.
        :rtype: list[User]
        """
        return self._work_item_user_assignees

    @work_item_user_assignees.setter
    def work_item_user_assignees(self, work_item_user_assignees):
        """
        Sets the work_item_user_assignees of this FlowReportResultItem.
        List of users currently assigned to a workItem

        :param work_item_user_assignees: The work_item_user_assignees of this FlowReportResultItem.
        :type: list[User]
        """
        self._work_item_user_assignees = work_item_user_assignees

    @property
    def completed_user(self):
        """
        Gets the completed_user of this FlowReportResultItem.
        User that completed the flow

        :return: The completed_user of this FlowReportResultItem.
        :rtype: User
        """
        return self._completed_user

    @completed_user.setter
    def completed_user(self, completed_user):
        """
        Sets the completed_user of this FlowReportResultItem.
        User that completed the flow

        :param completed_user: The completed_user of this FlowReportResultItem.
        :type: User
        """
        self._completed_user = completed_user

    @property
    def completion_reason(self):
        """
        Gets the completion_reason of this FlowReportResultItem.
        Reason for completion

        :return: The completion_reason of this FlowReportResultItem.
        :rtype: str
        """
        return self._completion_reason

    @completion_reason.setter
    def completion_reason(self, completion_reason):
        """
        Sets the completion_reason of this FlowReportResultItem.
        Reason for completion

        :param completion_reason: The completion_reason of this FlowReportResultItem.
        :type: str
        """
        self._completion_reason = completion_reason

    @property
    def flow_error_info(self):
        """
        Gets the flow_error_info of this FlowReportResultItem.
        Additional information if the flow is in error

        :return: The flow_error_info of this FlowReportResultItem.
        :rtype: ErrorBody
        """
        return self._flow_error_info

    @flow_error_info.setter
    def flow_error_info(self, flow_error_info):
        """
        Sets the flow_error_info of this FlowReportResultItem.
        Additional information if the flow is in error

        :param flow_error_info: The flow_error_info of this FlowReportResultItem.
        :type: ErrorBody
        """
        self._flow_error_info = flow_error_info

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DomainEdgeSoftwareVersionDto(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainEdgeSoftwareVersionDto - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'edge_version': 'str',
            'publish_date': 'datetime',
            'edge_uri': 'str',
            'current': 'bool',
            'latest_release': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'edge_version': 'edgeVersion',
            'publish_date': 'publishDate',
            'edge_uri': 'edgeUri',
            'current': 'current',
            'latest_release': 'latestRelease',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._edge_version = None
        self._publish_date = None
        self._edge_uri = None
        self._current = False
        self._latest_release = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DomainEdgeSoftwareVersionDto.
        The globally unique identifier for the object.

        :return: The id of this DomainEdgeSoftwareVersionDto.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DomainEdgeSoftwareVersionDto.
        The globally unique identifier for the object.

        :param id: The id of this DomainEdgeSoftwareVersionDto.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DomainEdgeSoftwareVersionDto.


        :return: The name of this DomainEdgeSoftwareVersionDto.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DomainEdgeSoftwareVersionDto.


        :param name: The name of this DomainEdgeSoftwareVersionDto.
        :type: str
        """
        self._name = name

    @property
    def edge_version(self):
        """
        Gets the edge_version of this DomainEdgeSoftwareVersionDto.


        :return: The edge_version of this DomainEdgeSoftwareVersionDto.
        :rtype: str
        """
        return self._edge_version

    @edge_version.setter
    def edge_version(self, edge_version):
        """
        Sets the edge_version of this DomainEdgeSoftwareVersionDto.


        :param edge_version: The edge_version of this DomainEdgeSoftwareVersionDto.
        :type: str
        """
        self._edge_version = edge_version

    @property
    def publish_date(self):
        """
        Gets the publish_date of this DomainEdgeSoftwareVersionDto.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The publish_date of this DomainEdgeSoftwareVersionDto.
        :rtype: datetime
        """
        return self._publish_date

    @publish_date.setter
    def publish_date(self, publish_date):
        """
        Sets the publish_date of this DomainEdgeSoftwareVersionDto.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param publish_date: The publish_date of this DomainEdgeSoftwareVersionDto.
        :type: datetime
        """
        self._publish_date = publish_date

    @property
    def edge_uri(self):
        """
        Gets the edge_uri of this DomainEdgeSoftwareVersionDto.


        :return: The edge_uri of this DomainEdgeSoftwareVersionDto.
        :rtype: str
        """
        return self._edge_uri

    @edge_uri.setter
    def edge_uri(self, edge_uri):
        """
        Sets the edge_uri of this DomainEdgeSoftwareVersionDto.


        :param edge_uri: The edge_uri of this DomainEdgeSoftwareVersionDto.
        :type: str
        """
        self._edge_uri = edge_uri

    @property
    def current(self):
        """
        Gets the current of this DomainEdgeSoftwareVersionDto.


        :return: The current of this DomainEdgeSoftwareVersionDto.
        :rtype: bool
        """
        return self._current

    @current.setter
    def current(self, current):
        """
        Sets the current of this DomainEdgeSoftwareVersionDto.


        :param current: The current of this DomainEdgeSoftwareVersionDto.
        :type: bool
        """
        self._current = current

    @property
    def latest_release(self):
        """
        Gets the latest_release of this DomainEdgeSoftwareVersionDto.


        :return: The latest_release of this DomainEdgeSoftwareVersionDto.
        :rtype: bool
        """
        return self._latest_release

    @latest_release.setter
    def latest_release(self, latest_release):
        """
        Sets the latest_release of this DomainEdgeSoftwareVersionDto.


        :param latest_release: The latest_release of this DomainEdgeSoftwareVersionDto.
        :type: bool
        """
        self._latest_release = latest_release

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DomainEdgeSoftwareVersionDto.
        The URI for this object

        :return: The self_uri of this DomainEdgeSoftwareVersionDto.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DomainEdgeSoftwareVersionDto.
        The URI for this object

        :param self_uri: The self_uri of this DomainEdgeSoftwareVersionDto.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

import sys
from setuptools import setup, find_packages

NAME = "PureCloudPlatformApiSdk"
VERSION = "0.7.0.45"



# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name="PureCloudPlatformApiSdk",
    version="0.7.0.45",
    description="PureCloud Platform API SDK",
    author="Interactive Intelligence, Inc.",
    author_email="DeveloperEvangelists@inin.com",
    url="https://developer.mypurecloud.com/api/rest/client-libraries/python/latest/",
    keywords=["Swagger PureCloud Platform API ININ Interactive Intelligence"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="A python package to interface with the PureCloud Platform API"
)





# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DependencyStatus(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DependencyStatus - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'user': 'User',
            'build_id': 'str',
            'date_started': 'datetime',
            'date_completed': 'datetime',
            'status': 'str',
            'failed_objects': 'list[FailedObject]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'user': 'user',
            'build_id': 'buildId',
            'date_started': 'dateStarted',
            'date_completed': 'dateCompleted',
            'status': 'status',
            'failed_objects': 'failedObjects',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._user = None
        self._build_id = None
        self._date_started = None
        self._date_completed = None
        self._status = None
        self._failed_objects = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DependencyStatus.
        The globally unique identifier for the object.

        :return: The id of this DependencyStatus.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DependencyStatus.
        The globally unique identifier for the object.

        :param id: The id of this DependencyStatus.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DependencyStatus.


        :return: The name of this DependencyStatus.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DependencyStatus.


        :param name: The name of this DependencyStatus.
        :type: str
        """
        self._name = name

    @property
    def user(self):
        """
        Gets the user of this DependencyStatus.


        :return: The user of this DependencyStatus.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this DependencyStatus.


        :param user: The user of this DependencyStatus.
        :type: User
        """
        self._user = user

    @property
    def build_id(self):
        """
        Gets the build_id of this DependencyStatus.


        :return: The build_id of this DependencyStatus.
        :rtype: str
        """
        return self._build_id

    @build_id.setter
    def build_id(self, build_id):
        """
        Sets the build_id of this DependencyStatus.


        :param build_id: The build_id of this DependencyStatus.
        :type: str
        """
        self._build_id = build_id

    @property
    def date_started(self):
        """
        Gets the date_started of this DependencyStatus.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_started of this DependencyStatus.
        :rtype: datetime
        """
        return self._date_started

    @date_started.setter
    def date_started(self, date_started):
        """
        Sets the date_started of this DependencyStatus.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_started: The date_started of this DependencyStatus.
        :type: datetime
        """
        self._date_started = date_started

    @property
    def date_completed(self):
        """
        Gets the date_completed of this DependencyStatus.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_completed of this DependencyStatus.
        :rtype: datetime
        """
        return self._date_completed

    @date_completed.setter
    def date_completed(self, date_completed):
        """
        Sets the date_completed of this DependencyStatus.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_completed: The date_completed of this DependencyStatus.
        :type: datetime
        """
        self._date_completed = date_completed

    @property
    def status(self):
        """
        Gets the status of this DependencyStatus.


        :return: The status of this DependencyStatus.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DependencyStatus.


        :param status: The status of this DependencyStatus.
        :type: str
        """
        allowed_values = ["BUILDINITIALIZING", "BUILDINPROGRESS", "NOTBUILT", "OPERATIONAL", "OPERATIONALNEEDSREBUILD"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def failed_objects(self):
        """
        Gets the failed_objects of this DependencyStatus.


        :return: The failed_objects of this DependencyStatus.
        :rtype: list[FailedObject]
        """
        return self._failed_objects

    @failed_objects.setter
    def failed_objects(self, failed_objects):
        """
        Sets the failed_objects of this DependencyStatus.


        :param failed_objects: The failed_objects of this DependencyStatus.
        :type: list[FailedObject]
        """
        self._failed_objects = failed_objects

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DependencyStatus.
        The URI for this object

        :return: The self_uri of this DependencyStatus.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DependencyStatus.
        The URI for this object

        :param self_uri: The self_uri of this DependencyStatus.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class OrganizationCreate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OrganizationCreate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'admin_username': 'str',
            'admin_password': 'str',
            'domain': 'str',
            'third_party_org_name': 'str',
            'deletable': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'admin_username': 'adminUsername',
            'admin_password': 'adminPassword',
            'domain': 'domain',
            'third_party_org_name': 'thirdPartyOrgName',
            'deletable': 'deletable'
        }

        self._name = None
        self._admin_username = None
        self._admin_password = None
        self._domain = None
        self._third_party_org_name = None
        self._deletable = False

    @property
    def name(self):
        """
        Gets the name of this OrganizationCreate.
        Display Name for Organization

        :return: The name of this OrganizationCreate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OrganizationCreate.
        Display Name for Organization

        :param name: The name of this OrganizationCreate.
        :type: str
        """
        self._name = name

    @property
    def admin_username(self):
        """
        Gets the admin_username of this OrganizationCreate.
        Administrator username for this organization

        :return: The admin_username of this OrganizationCreate.
        :rtype: str
        """
        return self._admin_username

    @admin_username.setter
    def admin_username(self, admin_username):
        """
        Sets the admin_username of this OrganizationCreate.
        Administrator username for this organization

        :param admin_username: The admin_username of this OrganizationCreate.
        :type: str
        """
        self._admin_username = admin_username

    @property
    def admin_password(self):
        """
        Gets the admin_password of this OrganizationCreate.
        Administrator password for this organization

        :return: The admin_password of this OrganizationCreate.
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """
        Sets the admin_password of this OrganizationCreate.
        Administrator password for this organization

        :param admin_password: The admin_password of this OrganizationCreate.
        :type: str
        """
        self._admin_password = admin_password

    @property
    def domain(self):
        """
        Gets the domain of this OrganizationCreate.
        Fully qualified domain name for this organization (Ex. example.com).

        :return: The domain of this OrganizationCreate.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this OrganizationCreate.
        Fully qualified domain name for this organization (Ex. example.com).

        :param domain: The domain of this OrganizationCreate.
        :type: str
        """
        self._domain = domain

    @property
    def third_party_org_name(self):
        """
        Gets the third_party_org_name of this OrganizationCreate.
        Organization Name which does not contain special characters like spaces.

        :return: The third_party_org_name of this OrganizationCreate.
        :rtype: str
        """
        return self._third_party_org_name

    @third_party_org_name.setter
    def third_party_org_name(self, third_party_org_name):
        """
        Sets the third_party_org_name of this OrganizationCreate.
        Organization Name which does not contain special characters like spaces.

        :param third_party_org_name: The third_party_org_name of this OrganizationCreate.
        :type: str
        """
        self._third_party_org_name = third_party_org_name

    @property
    def deletable(self):
        """
        Gets the deletable of this OrganizationCreate.
        Deletable Property for Organization.

        :return: The deletable of this OrganizationCreate.
        :rtype: bool
        """
        return self._deletable

    @deletable.setter
    def deletable(self, deletable):
        """
        Sets the deletable of this OrganizationCreate.
        Deletable Property for Organization.

        :param deletable: The deletable of this OrganizationCreate.
        :type: bool
        """
        self._deletable = deletable

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class SocialAccount(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SocialAccount - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'enabled': 'bool',
            'authorized': 'bool',
            'social_hub': 'str',
            'access_token': 'str',
            'access_token_secret': 'str',
            'twitter_id': 'str',
            'streaming_enabled': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'enabled': 'enabled',
            'authorized': 'authorized',
            'social_hub': 'socialHub',
            'access_token': 'access_token',
            'access_token_secret': 'access_token_secret',
            'twitter_id': 'twitterId',
            'streaming_enabled': 'streamingEnabled',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._enabled = False
        self._authorized = False
        self._social_hub = None
        self._access_token = None
        self._access_token_secret = None
        self._twitter_id = None
        self._streaming_enabled = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this SocialAccount.
        The globally unique identifier for the object.

        :return: The id of this SocialAccount.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SocialAccount.
        The globally unique identifier for the object.

        :param id: The id of this SocialAccount.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this SocialAccount.


        :return: The name of this SocialAccount.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SocialAccount.


        :param name: The name of this SocialAccount.
        :type: str
        """
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this SocialAccount.
        Creation date for the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this SocialAccount.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this SocialAccount.
        Creation date for the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this SocialAccount.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this SocialAccount.
        Date the entity was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this SocialAccount.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this SocialAccount.
        Date the entity was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this SocialAccount.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def enabled(self):
        """
        Gets the enabled of this SocialAccount.
        Indicates if this Social Account is available for selection by other entities

        :return: The enabled of this SocialAccount.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this SocialAccount.
        Indicates if this Social Account is available for selection by other entities

        :param enabled: The enabled of this SocialAccount.
        :type: bool
        """
        self._enabled = enabled

    @property
    def authorized(self):
        """
        Gets the authorized of this SocialAccount.
        True when successfully completing the third-party authorization process

        :return: The authorized of this SocialAccount.
        :rtype: bool
        """
        return self._authorized

    @authorized.setter
    def authorized(self, authorized):
        """
        Sets the authorized of this SocialAccount.
        True when successfully completing the third-party authorization process

        :param authorized: The authorized of this SocialAccount.
        :type: bool
        """
        self._authorized = authorized

    @property
    def social_hub(self):
        """
        Gets the social_hub of this SocialAccount.
        Which third party Social Media Hub this account will be communicating through

        :return: The social_hub of this SocialAccount.
        :rtype: str
        """
        return self._social_hub

    @social_hub.setter
    def social_hub(self, social_hub):
        """
        Sets the social_hub of this SocialAccount.
        Which third party Social Media Hub this account will be communicating through

        :param social_hub: The social_hub of this SocialAccount.
        :type: str
        """
        self._social_hub = social_hub

    @property
    def access_token(self):
        """
        Gets the access_token of this SocialAccount.
        Credential provided through the Social Hub's authorization process

        :return: The access_token of this SocialAccount.
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """
        Sets the access_token of this SocialAccount.
        Credential provided through the Social Hub's authorization process

        :param access_token: The access_token of this SocialAccount.
        :type: str
        """
        self._access_token = access_token

    @property
    def access_token_secret(self):
        """
        Gets the access_token_secret of this SocialAccount.
        Credential provided through the Social Hub's authorization process

        :return: The access_token_secret of this SocialAccount.
        :rtype: str
        """
        return self._access_token_secret

    @access_token_secret.setter
    def access_token_secret(self, access_token_secret):
        """
        Sets the access_token_secret of this SocialAccount.
        Credential provided through the Social Hub's authorization process

        :param access_token_secret: The access_token_secret of this SocialAccount.
        :type: str
        """
        self._access_token_secret = access_token_secret

    @property
    def twitter_id(self):
        """
        Gets the twitter_id of this SocialAccount.
        The account ID as provided by Twitter during the authorization process

        :return: The twitter_id of this SocialAccount.
        :rtype: str
        """
        return self._twitter_id

    @twitter_id.setter
    def twitter_id(self, twitter_id):
        """
        Sets the twitter_id of this SocialAccount.
        The account ID as provided by Twitter during the authorization process

        :param twitter_id: The twitter_id of this SocialAccount.
        :type: str
        """
        self._twitter_id = twitter_id

    @property
    def streaming_enabled(self):
        """
        Gets the streaming_enabled of this SocialAccount.
        Indicates if a stream should be opened on behalf of the indicated Social Hub account

        :return: The streaming_enabled of this SocialAccount.
        :rtype: bool
        """
        return self._streaming_enabled

    @streaming_enabled.setter
    def streaming_enabled(self, streaming_enabled):
        """
        Sets the streaming_enabled of this SocialAccount.
        Indicates if a stream should be opened on behalf of the indicated Social Hub account

        :param streaming_enabled: The streaming_enabled of this SocialAccount.
        :type: bool
        """
        self._streaming_enabled = streaming_enabled

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SocialAccount.
        The URI for this object

        :return: The self_uri of this SocialAccount.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SocialAccount.
        The URI for this object

        :param self_uri: The self_uri of this SocialAccount.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
SearchApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class SearchApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_search(self, **kwargs):
        """
        Search using q64
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_search(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str q64: 
        :param list[str] expand: 
        :return: GroupsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['q64', 'expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_search" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/groups/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'q64' in params:
            query_params['q64'] = params['q64']
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GroupsSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_search_0(self, **kwargs):
        """
        Search using q64
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_search_0(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str q64: 
        :param list[str] expand: 
        :return: JsonNodeSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['q64', 'expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_search_0" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'q64' in params:
            query_params['q64'] = params['q64']
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='JsonNodeSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_search_1(self, **kwargs):
        """
        Search using q64
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_search_1(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str q64: 
        :param list[str] expand: 
        :return: UsersSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['q64', 'expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_search_1" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/users/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'q64' in params:
            query_params['q64'] = params['q64']
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UsersSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_search(self, **kwargs):
        """
        Search
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_search(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SearchRequest body: Search request options
        :return: GroupsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_search" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/groups/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GroupsSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_search_0(self, **kwargs):
        """
        Search
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_search_0(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SearchRequest body: Search request options
        :return: JsonNodeSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_search_0" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='JsonNodeSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_search_1(self, **kwargs):
        """
        Search
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_search_1(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param SearchRequest body: Search request options
        :return: UsersSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_search_1" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/users/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UsersSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class CampaignSchedule(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignSchedule - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'intervals': 'list[CampaignScheduleIntervals]',
            'time_zone': 'str',
            'campaign': 'UriReference',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'intervals': 'intervals',
            'time_zone': 'timeZone',
            'campaign': 'campaign',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._intervals = None
        self._time_zone = None
        self._campaign = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this CampaignSchedule.
        The globally unique identifier for the object.

        :return: The id of this CampaignSchedule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CampaignSchedule.
        The globally unique identifier for the object.

        :param id: The id of this CampaignSchedule.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CampaignSchedule.


        :return: The name of this CampaignSchedule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CampaignSchedule.


        :param name: The name of this CampaignSchedule.
        :type: str
        """
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this CampaignSchedule.
        creation time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this CampaignSchedule.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this CampaignSchedule.
        creation time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this CampaignSchedule.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this CampaignSchedule.
        last modified time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this CampaignSchedule.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this CampaignSchedule.
        last modified time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this CampaignSchedule.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this CampaignSchedule.
        required for updates, must match the version number of the most recent update

        :return: The version of this CampaignSchedule.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this CampaignSchedule.
        required for updates, must match the version number of the most recent update

        :param version: The version of this CampaignSchedule.
        :type: int
        """
        self._version = version

    @property
    def intervals(self):
        """
        Gets the intervals of this CampaignSchedule.


        :return: The intervals of this CampaignSchedule.
        :rtype: list[CampaignScheduleIntervals]
        """
        return self._intervals

    @intervals.setter
    def intervals(self, intervals):
        """
        Sets the intervals of this CampaignSchedule.


        :param intervals: The intervals of this CampaignSchedule.
        :type: list[CampaignScheduleIntervals]
        """
        self._intervals = intervals

    @property
    def time_zone(self):
        """
        Gets the time_zone of this CampaignSchedule.


        :return: The time_zone of this CampaignSchedule.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this CampaignSchedule.


        :param time_zone: The time_zone of this CampaignSchedule.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def campaign(self):
        """
        Gets the campaign of this CampaignSchedule.


        :return: The campaign of this CampaignSchedule.
        :rtype: UriReference
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """
        Sets the campaign of this CampaignSchedule.


        :param campaign: The campaign of this CampaignSchedule.
        :type: UriReference
        """
        self._campaign = campaign

    @property
    def self_uri(self):
        """
        Gets the self_uri of this CampaignSchedule.
        The URI for this object

        :return: The self_uri of this CampaignSchedule.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this CampaignSchedule.
        The URI for this object

        :param self_uri: The self_uri of this CampaignSchedule.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FacetRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FacetRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'facet_request_query_type': 'str',
            'field_name': 'str',
            'type': 'str',
            'range_from': 'str',
            'range_to': 'str',
            'max_facet_count': 'int'
        }

        self.attribute_map = {
            'name': 'name',
            'facet_request_query_type': 'facetRequestQueryType',
            'field_name': 'fieldName',
            'type': 'type',
            'range_from': 'rangeFrom',
            'range_to': 'rangeTo',
            'max_facet_count': 'maxFacetCount'
        }

        self._name = None
        self._facet_request_query_type = None
        self._field_name = None
        self._type = None
        self._range_from = None
        self._range_to = None
        self._max_facet_count = None

    @property
    def name(self):
        """
        Gets the name of this FacetRequest.
        name of the facet request that will be returned with the result set

        :return: The name of this FacetRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FacetRequest.
        name of the facet request that will be returned with the result set

        :param name: The name of this FacetRequest.
        :type: str
        """
        self._name = name

    @property
    def facet_request_query_type(self):
        """
        Gets the facet_request_query_type of this FacetRequest.
        Which facet request type

        :return: The facet_request_query_type of this FacetRequest.
        :rtype: str
        """
        return self._facet_request_query_type

    @facet_request_query_type.setter
    def facet_request_query_type(self, facet_request_query_type):
        """
        Sets the facet_request_query_type of this FacetRequest.
        Which facet request type

        :param facet_request_query_type: The facet_request_query_type of this FacetRequest.
        :type: str
        """
        allowed_values = ["TERM", "RANGE"]
        if facet_request_query_type not in allowed_values:
            raise ValueError(
                "Invalid value for `facet_request_query_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._facet_request_query_type = facet_request_query_type

    @property
    def field_name(self):
        """
        Gets the field_name of this FacetRequest.
        The fieldName to perform the facet request on.

        :return: The field_name of this FacetRequest.
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """
        Sets the field_name of this FacetRequest.
        The fieldName to perform the facet request on.

        :param field_name: The field_name of this FacetRequest.
        :type: str
        """
        self._field_name = field_name

    @property
    def type(self):
        """
        Gets the type of this FacetRequest.
        the fieldtype of the field to perform the facet request on.

        :return: The type of this FacetRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this FacetRequest.
        the fieldtype of the field to perform the facet request on.

        :param type: The type of this FacetRequest.
        :type: str
        """
        allowed_values = ["NUMBER", "STRING", "DATE", "BOOLEAN", "LIST", "GROUP"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def range_from(self):
        """
        Gets the range_from of this FacetRequest.
        For RANGE requests populate this field to specify the beginning of a limit (leave blank for openended).  Note this value is inclusive of the results.  (EG if the value is 1, 1 will be included in the range.)

        :return: The range_from of this FacetRequest.
        :rtype: str
        """
        return self._range_from

    @range_from.setter
    def range_from(self, range_from):
        """
        Sets the range_from of this FacetRequest.
        For RANGE requests populate this field to specify the beginning of a limit (leave blank for openended).  Note this value is inclusive of the results.  (EG if the value is 1, 1 will be included in the range.)

        :param range_from: The range_from of this FacetRequest.
        :type: str
        """
        self._range_from = range_from

    @property
    def range_to(self):
        """
        Gets the range_to of this FacetRequest.
        For RANGE requests populate this field to specify the end of a limit (leave blank for openended).  Note this value is EXCLUSIVE of the result (EG if this value was 5, only values LESS THAN 5 will be included in the count.)

        :return: The range_to of this FacetRequest.
        :rtype: str
        """
        return self._range_to

    @range_to.setter
    def range_to(self, range_to):
        """
        Sets the range_to of this FacetRequest.
        For RANGE requests populate this field to specify the end of a limit (leave blank for openended).  Note this value is EXCLUSIVE of the result (EG if this value was 5, only values LESS THAN 5 will be included in the count.)

        :param range_to: The range_to of this FacetRequest.
        :type: str
        """
        self._range_to = range_to

    @property
    def max_facet_count(self):
        """
        Gets the max_facet_count of this FacetRequest.
        Limits/expands the number of facet entries returned (default 500)

        :return: The max_facet_count of this FacetRequest.
        :rtype: int
        """
        return self._max_facet_count

    @max_facet_count.setter
    def max_facet_count(self, max_facet_count):
        """
        Sets the max_facet_count of this FacetRequest.
        Limits/expands the number of facet entries returned (default 500)

        :param max_facet_count: The max_facet_count of this FacetRequest.
        :type: int
        """
        self._max_facet_count = max_facet_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Video(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Video - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'context': 'str',
            'audio_muted': 'bool',
            'video_muted': 'bool',
            'sharing_screen': 'bool',
            'peer_count': 'int',
            'disconnect_type': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'context': 'context',
            'audio_muted': 'audioMuted',
            'video_muted': 'videoMuted',
            'sharing_screen': 'sharingScreen',
            'peer_count': 'peerCount',
            'disconnect_type': 'disconnectType',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime'
        }

        self._state = None
        self._id = None
        self._context = None
        self._audio_muted = False
        self._video_muted = False
        self._sharing_screen = False
        self._peer_count = None
        self._disconnect_type = None
        self._connected_time = None
        self._disconnected_time = None

    @property
    def state(self):
        """
        Gets the state of this Video.


        :return: The state of this Video.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Video.


        :param state: The state of this Video.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def id(self):
        """
        Gets the id of this Video.


        :return: The id of this Video.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Video.


        :param id: The id of this Video.
        :type: str
        """
        self._id = id

    @property
    def context(self):
        """
        Gets the context of this Video.


        :return: The context of this Video.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this Video.


        :param context: The context of this Video.
        :type: str
        """
        self._context = context

    @property
    def audio_muted(self):
        """
        Gets the audio_muted of this Video.


        :return: The audio_muted of this Video.
        :rtype: bool
        """
        return self._audio_muted

    @audio_muted.setter
    def audio_muted(self, audio_muted):
        """
        Sets the audio_muted of this Video.


        :param audio_muted: The audio_muted of this Video.
        :type: bool
        """
        self._audio_muted = audio_muted

    @property
    def video_muted(self):
        """
        Gets the video_muted of this Video.


        :return: The video_muted of this Video.
        :rtype: bool
        """
        return self._video_muted

    @video_muted.setter
    def video_muted(self, video_muted):
        """
        Sets the video_muted of this Video.


        :param video_muted: The video_muted of this Video.
        :type: bool
        """
        self._video_muted = video_muted

    @property
    def sharing_screen(self):
        """
        Gets the sharing_screen of this Video.


        :return: The sharing_screen of this Video.
        :rtype: bool
        """
        return self._sharing_screen

    @sharing_screen.setter
    def sharing_screen(self, sharing_screen):
        """
        Sets the sharing_screen of this Video.


        :param sharing_screen: The sharing_screen of this Video.
        :type: bool
        """
        self._sharing_screen = sharing_screen

    @property
    def peer_count(self):
        """
        Gets the peer_count of this Video.


        :return: The peer_count of this Video.
        :rtype: int
        """
        return self._peer_count

    @peer_count.setter
    def peer_count(self, peer_count):
        """
        Sets the peer_count of this Video.


        :param peer_count: The peer_count of this Video.
        :type: int
        """
        self._peer_count = peer_count

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this Video.


        :return: The disconnect_type of this Video.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this Video.


        :param disconnect_type: The disconnect_type of this Video.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "ERROR", "PEER", "OTHER"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._disconnect_type = disconnect_type

    @property
    def connected_time(self):
        """
        Gets the connected_time of this Video.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The connected_time of this Video.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this Video.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param connected_time: The connected_time of this Video.
        :type: datetime
        """
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this Video.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The disconnected_time of this Video.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this Video.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param disconnected_time: The disconnected_time of this Video.
        :type: datetime
        """
        self._disconnected_time = disconnected_time

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ResourceConditionNode(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ResourceConditionNode - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'variable_name': 'str',
            'conjunction': 'str',
            'operator': 'str',
            'operands': 'list[ResourceConditionValue]',
            'terms': 'list[ResourceConditionNode]'
        }

        self.attribute_map = {
            'variable_name': 'variableName',
            'conjunction': 'conjunction',
            'operator': 'operator',
            'operands': 'operands',
            'terms': 'terms'
        }

        self._variable_name = None
        self._conjunction = None
        self._operator = None
        self._operands = None
        self._terms = None

    @property
    def variable_name(self):
        """
        Gets the variable_name of this ResourceConditionNode.


        :return: The variable_name of this ResourceConditionNode.
        :rtype: str
        """
        return self._variable_name

    @variable_name.setter
    def variable_name(self, variable_name):
        """
        Sets the variable_name of this ResourceConditionNode.


        :param variable_name: The variable_name of this ResourceConditionNode.
        :type: str
        """
        self._variable_name = variable_name

    @property
    def conjunction(self):
        """
        Gets the conjunction of this ResourceConditionNode.


        :return: The conjunction of this ResourceConditionNode.
        :rtype: str
        """
        return self._conjunction

    @conjunction.setter
    def conjunction(self, conjunction):
        """
        Sets the conjunction of this ResourceConditionNode.


        :param conjunction: The conjunction of this ResourceConditionNode.
        :type: str
        """
        allowed_values = ["AND", "OR"]
        if conjunction not in allowed_values:
            raise ValueError(
                "Invalid value for `conjunction`, must be one of {0}"
                .format(allowed_values)
            )
        self._conjunction = conjunction

    @property
    def operator(self):
        """
        Gets the operator of this ResourceConditionNode.


        :return: The operator of this ResourceConditionNode.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this ResourceConditionNode.


        :param operator: The operator of this ResourceConditionNode.
        :type: str
        """
        allowed_values = ["EQ", "IN", "GE", "GT", "LE", "LT"]
        if operator not in allowed_values:
            raise ValueError(
                "Invalid value for `operator`, must be one of {0}"
                .format(allowed_values)
            )
        self._operator = operator

    @property
    def operands(self):
        """
        Gets the operands of this ResourceConditionNode.


        :return: The operands of this ResourceConditionNode.
        :rtype: list[ResourceConditionValue]
        """
        return self._operands

    @operands.setter
    def operands(self, operands):
        """
        Sets the operands of this ResourceConditionNode.


        :param operands: The operands of this ResourceConditionNode.
        :type: list[ResourceConditionValue]
        """
        self._operands = operands

    @property
    def terms(self):
        """
        Gets the terms of this ResourceConditionNode.


        :return: The terms of this ResourceConditionNode.
        :rtype: list[ResourceConditionNode]
        """
        return self._terms

    @terms.setter
    def terms(self, terms):
        """
        Sets the terms of this ResourceConditionNode.


        :param terms: The terms of this ResourceConditionNode.
        :type: list[ResourceConditionNode]
        """
        self._terms = terms

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class TextTableTransform(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TextTableTransform - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'rest_endpoint': 'TransformEndpoint',
            'filename_transforms': 'list[BasicTransform]',
            'tags': 'list[TagModel]',
            'comment_symbol': 'str',
            'delimiter': 'str',
            'table': 'TableTransform',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'rest_endpoint': 'restEndpoint',
            'filename_transforms': 'filenameTransforms',
            'tags': 'tags',
            'comment_symbol': 'commentSymbol',
            'delimiter': 'delimiter',
            'table': 'table',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._rest_endpoint = None
        self._filename_transforms = None
        self._tags = None
        self._comment_symbol = None
        self._delimiter = None
        self._table = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TextTableTransform.
        The globally unique identifier for the object.

        :return: The id of this TextTableTransform.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TextTableTransform.
        The globally unique identifier for the object.

        :param id: The id of this TextTableTransform.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TextTableTransform.


        :return: The name of this TextTableTransform.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TextTableTransform.


        :param name: The name of this TextTableTransform.
        :type: str
        """
        self._name = name

    @property
    def rest_endpoint(self):
        """
        Gets the rest_endpoint of this TextTableTransform.


        :return: The rest_endpoint of this TextTableTransform.
        :rtype: TransformEndpoint
        """
        return self._rest_endpoint

    @rest_endpoint.setter
    def rest_endpoint(self, rest_endpoint):
        """
        Sets the rest_endpoint of this TextTableTransform.


        :param rest_endpoint: The rest_endpoint of this TextTableTransform.
        :type: TransformEndpoint
        """
        self._rest_endpoint = rest_endpoint

    @property
    def filename_transforms(self):
        """
        Gets the filename_transforms of this TextTableTransform.


        :return: The filename_transforms of this TextTableTransform.
        :rtype: list[BasicTransform]
        """
        return self._filename_transforms

    @filename_transforms.setter
    def filename_transforms(self, filename_transforms):
        """
        Sets the filename_transforms of this TextTableTransform.


        :param filename_transforms: The filename_transforms of this TextTableTransform.
        :type: list[BasicTransform]
        """
        self._filename_transforms = filename_transforms

    @property
    def tags(self):
        """
        Gets the tags of this TextTableTransform.


        :return: The tags of this TextTableTransform.
        :rtype: list[TagModel]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this TextTableTransform.


        :param tags: The tags of this TextTableTransform.
        :type: list[TagModel]
        """
        self._tags = tags

    @property
    def comment_symbol(self):
        """
        Gets the comment_symbol of this TextTableTransform.


        :return: The comment_symbol of this TextTableTransform.
        :rtype: str
        """
        return self._comment_symbol

    @comment_symbol.setter
    def comment_symbol(self, comment_symbol):
        """
        Sets the comment_symbol of this TextTableTransform.


        :param comment_symbol: The comment_symbol of this TextTableTransform.
        :type: str
        """
        self._comment_symbol = comment_symbol

    @property
    def delimiter(self):
        """
        Gets the delimiter of this TextTableTransform.


        :return: The delimiter of this TextTableTransform.
        :rtype: str
        """
        return self._delimiter

    @delimiter.setter
    def delimiter(self, delimiter):
        """
        Sets the delimiter of this TextTableTransform.


        :param delimiter: The delimiter of this TextTableTransform.
        :type: str
        """
        self._delimiter = delimiter

    @property
    def table(self):
        """
        Gets the table of this TextTableTransform.


        :return: The table of this TextTableTransform.
        :rtype: TableTransform
        """
        return self._table

    @table.setter
    def table(self, table):
        """
        Sets the table of this TextTableTransform.


        :param table: The table of this TextTableTransform.
        :type: TableTransform
        """
        self._table = table

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TextTableTransform.
        The URI for this object

        :return: The self_uri of this TextTableTransform.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TextTableTransform.
        The URI for this object

        :param self_uri: The self_uri of this TextTableTransform.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
RecordingApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class RecordingApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_conversation_id_recordings_recording_id_annotations_annotation_id(self, conversation_id, recording_id, annotation_id, **kwargs):
        """
        Delete annotation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_conversation_id_recordings_recording_id_annotations_annotation_id(conversation_id, recording_id, annotation_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str recording_id: Recording ID (required)
        :param str annotation_id: Annotation ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'recording_id', 'annotation_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_conversation_id_recordings_recording_id_annotations_annotation_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `delete_conversation_id_recordings_recording_id_annotations_annotation_id`")
        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `delete_conversation_id_recordings_recording_id_annotations_annotation_id`")
        # verify the required parameter 'annotation_id' is set
        if ('annotation_id' not in params) or (params['annotation_id'] is None):
            raise ValueError("Missing the required parameter `annotation_id` when calling `delete_conversation_id_recordings_recording_id_annotations_annotation_id`")

        resource_path = '/api/v2/conversations/{conversationId}/recordings/{recordingId}/annotations/{annotationId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']
        if 'annotation_id' in params:
            path_params['annotationId'] = params['annotation_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_mediaretentionpolicies(self, ids, **kwargs):
        """
        Delete media retention policies
        Bulk delete of media retention policies, this will only delete the polices that match the ids specified in the query param.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_mediaretentionpolicies(ids, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str ids:  (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ids']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_mediaretentionpolicies" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'ids' is set
        if ('ids' not in params) or (params['ids'] is None):
            raise ValueError("Missing the required parameter `ids` when calling `delete_mediaretentionpolicies`")

        resource_path = '/api/v2/recording/mediaretentionpolicies'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'ids' in params:
            query_params['ids'] = params['ids']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='str',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_mediaretentionpolicies_policy_id(self, policy_id, **kwargs):
        """
        Delete a media retention policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_mediaretentionpolicies_policy_id(policy_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str policy_id: Policy ID (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_mediaretentionpolicies_policy_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'policy_id' is set
        if ('policy_id' not in params) or (params['policy_id'] is None):
            raise ValueError("Missing the required parameter `policy_id` when calling `delete_mediaretentionpolicies_policy_id`")

        resource_path = '/api/v2/recording/mediaretentionpolicies/{policyId}'.replace('{format}', 'json')
        path_params = {}
        if 'policy_id' in params:
            path_params['policyId'] = params['policy_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='str',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_orphan_id(self, orphan_id, **kwargs):
        """
         deletes a single orphan recording
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_orphan_id(orphan_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str orphan_id: Orphan ID (required)
        :return: OrphanRecording
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['orphan_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_orphan_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'orphan_id' is set
        if ('orphan_id' not in params) or (params['orphan_id'] is None):
            raise ValueError("Missing the required parameter `orphan_id` when calling `delete_orphan_id`")

        resource_path = '/api/v2/orphanrecordings/{orphanId}'.replace('{format}', 'json')
        path_params = {}
        if 'orphan_id' in params:
            path_params['orphanId'] = params['orphan_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrphanRecording',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_conversation_id_recordings(self, conversation_id, **kwargs):
        """
        Get all of a Conversation's Recordings.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_conversation_id_recordings(conversation_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str format_id: The desired media format (WEBM, WAV)
        :return: list[Recording]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'format_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conversation_id_recordings" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_conversation_id_recordings`")

        resource_path = '/api/v2/conversations/{conversationId}/recordings'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']

        query_params = {}
        if 'format_id' in params:
            query_params['formatId'] = params['format_id']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[Recording]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_conversation_id_recordings_recording_id(self, conversation_id, recording_id, **kwargs):
        """
        Gets a specific recording.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_conversation_id_recordings_recording_id(conversation_id, recording_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str recording_id: Recording ID (required)
        :param str format_id: The desired media format (WEBM, WAV)
        :param bool download: requesting a download format of the recording
        :param str file_name: the name of the downloaded fileName
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'recording_id', 'format_id', 'download', 'file_name']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conversation_id_recordings_recording_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_conversation_id_recordings_recording_id`")
        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `get_conversation_id_recordings_recording_id`")

        resource_path = '/api/v2/conversations/{conversationId}/recordings/{recordingId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']

        query_params = {}
        if 'format_id' in params:
            query_params['formatId'] = params['format_id']
        if 'download' in params:
            query_params['download'] = params['download']
        if 'file_name' in params:
            query_params['fileName'] = params['file_name']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_conversation_id_recordings_recording_id_annotations(self, conversation_id, recording_id, **kwargs):
        """
        Get annotations for recording
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_conversation_id_recordings_recording_id_annotations(conversation_id, recording_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str recording_id: Recording ID (required)
        :return: list[Annotation]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'recording_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conversation_id_recordings_recording_id_annotations" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_conversation_id_recordings_recording_id_annotations`")
        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `get_conversation_id_recordings_recording_id_annotations`")

        resource_path = '/api/v2/conversations/{conversationId}/recordings/{recordingId}/annotations'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[Annotation]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_conversation_id_recordings_recording_id_annotations_annotation_id(self, conversation_id, recording_id, annotation_id, **kwargs):
        """
        Get annotation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_conversation_id_recordings_recording_id_annotations_annotation_id(conversation_id, recording_id, annotation_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str recording_id: Recording ID (required)
        :param str annotation_id: Annotation ID (required)
        :return: Annotation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'recording_id', 'annotation_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conversation_id_recordings_recording_id_annotations_annotation_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `get_conversation_id_recordings_recording_id_annotations_annotation_id`")
        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `get_conversation_id_recordings_recording_id_annotations_annotation_id`")
        # verify the required parameter 'annotation_id' is set
        if ('annotation_id' not in params) or (params['annotation_id'] is None):
            raise ValueError("Missing the required parameter `annotation_id` when calling `get_conversation_id_recordings_recording_id_annotations_annotation_id`")

        resource_path = '/api/v2/conversations/{conversationId}/recordings/{recordingId}/annotations/{annotationId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']
        if 'annotation_id' in params:
            path_params['annotationId'] = params['annotation_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Annotation',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_mediaretentionpolicies(self, **kwargs):
        """
        Gets media retention policy list with query options to filter on name and enabled.
        for a less verbose response, add summary=true to this endpoint

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_mediaretentionpolicies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: The total page size requested
        :param int page_number: The page number requested
        :param str sort_by: variable name requested to sort by
        :param list[str] expand: variable name requested by expand list
        :param str next_page: next page token
        :param str previous_page: Previous page token
        :param str name: the policy name - used for filtering results in searches.
        :param bool enabled: checks to see if policy is enabled - use enabled = true or enabled = false
        :param bool summary: provides a less verbose response of policy lists.
        :param bool has_errors: provides a way to fetch all policies with errors or policies that do not have errors
        :return: PolicyEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'sort_by', 'expand', 'next_page', 'previous_page', 'name', 'enabled', 'summary', 'has_errors']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mediaretentionpolicies" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/recording/mediaretentionpolicies'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_by' in params:
            query_params['sortBy'] = params['sort_by']
        if 'expand' in params:
            query_params['expand'] = params['expand']
        if 'next_page' in params:
            query_params['nextPage'] = params['next_page']
        if 'previous_page' in params:
            query_params['previousPage'] = params['previous_page']
        if 'name' in params:
            query_params['name'] = params['name']
        if 'enabled' in params:
            query_params['enabled'] = params['enabled']
        if 'summary' in params:
            query_params['summary'] = params['summary']
        if 'has_errors' in params:
            query_params['hasErrors'] = params['has_errors']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='PolicyEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_mediaretentionpolicies_policy_id(self, policy_id, **kwargs):
        """
        Get a media retention policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_mediaretentionpolicies_policy_id(policy_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str policy_id: Policy ID (required)
        :return: Policy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_mediaretentionpolicies_policy_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'policy_id' is set
        if ('policy_id' not in params) or (params['policy_id'] is None):
            raise ValueError("Missing the required parameter `policy_id` when calling `get_mediaretentionpolicies_policy_id`")

        resource_path = '/api/v2/recording/mediaretentionpolicies/{policyId}'.replace('{format}', 'json')
        path_params = {}
        if 'policy_id' in params:
            path_params['policyId'] = params['policy_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Policy',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orphan_id(self, orphan_id, **kwargs):
        """
        Gets a single orphan recording
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orphan_id(orphan_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str orphan_id: Orphan ID (required)
        :return: OrphanRecording
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['orphan_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orphan_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'orphan_id' is set
        if ('orphan_id' not in params) or (params['orphan_id'] is None):
            raise ValueError("Missing the required parameter `orphan_id` when calling `get_orphan_id`")

        resource_path = '/api/v2/orphanrecordings/{orphanId}'.replace('{format}', 'json')
        path_params = {}
        if 'orphan_id' in params:
            path_params['orphanId'] = params['orphan_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrphanRecording',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_orphanrecordings(self, **kwargs):
        """
        Gets all orphan recordings
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_orphanrecordings(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: The total page size requested
        :param int page_number: The page number requested
        :param str sort_by: variable name requested to sort by
        :param list[str] expand: variable name requested by expand list
        :param str next_page: next page token
        :param str previous_page: Previous page token
        :return: OrphanRecordingListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'sort_by', 'expand', 'next_page', 'previous_page']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_orphanrecordings" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/orphanrecordings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_by' in params:
            query_params['sortBy'] = params['sort_by']
        if 'expand' in params:
            query_params['expand'] = params['expand']
        if 'next_page' in params:
            query_params['nextPage'] = params['next_page']
        if 'previous_page' in params:
            query_params['previousPage'] = params['previous_page']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrphanRecordingListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_settings(self, **kwargs):
        """
        Get the Recording Settings for the Organization
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_settings(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param bool create_default: If no settings are found, a new one is created with default values
        :return: RecordingSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_default']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_settings" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/recording/settings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'create_default' in params:
            query_params['createDefault'] = params['create_default']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='RecordingSettings',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def patch_mediaretentionpolicies_policy_id(self, policy_id, **kwargs):
        """
        Patch a media retention policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_mediaretentionpolicies_policy_id(policy_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str policy_id: Policy ID (required)
        :param Policy body: Policy
        :return: Policy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_mediaretentionpolicies_policy_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'policy_id' is set
        if ('policy_id' not in params) or (params['policy_id'] is None):
            raise ValueError("Missing the required parameter `policy_id` when calling `patch_mediaretentionpolicies_policy_id`")

        resource_path = '/api/v2/recording/mediaretentionpolicies/{policyId}'.replace('{format}', 'json')
        path_params = {}
        if 'policy_id' in params:
            path_params['policyId'] = params['policy_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PATCH',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Policy',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_conversation_id_recordings_recording_id_annotations(self, conversation_id, recording_id, **kwargs):
        """
        Create annotation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_conversation_id_recordings_recording_id_annotations(conversation_id, recording_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str recording_id: Recording ID (required)
        :param Annotation body: annotation
        :return: Annotation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'recording_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_conversation_id_recordings_recording_id_annotations" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `post_conversation_id_recordings_recording_id_annotations`")
        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `post_conversation_id_recordings_recording_id_annotations`")

        resource_path = '/api/v2/conversations/{conversationId}/recordings/{recordingId}/annotations'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Annotation',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_mediaretentionpolicies(self, **kwargs):
        """
        Create media retention policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_mediaretentionpolicies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Policy body: Policy
        :return: Policy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_mediaretentionpolicies" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/recording/mediaretentionpolicies'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Policy',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_conversation_id_recordings_recording_id(self, conversation_id, recording_id, body, **kwargs):
        """
        Updates the retention records on a recording.
        Currently supports updating and removing both archive and delete dates for eligible recordings. A request to change the archival date of an archived recording will result in a restoration of the recording until the new date set. Use of the query parameter 'restoreDays' is deprecated and will be removed in the next major version release. If 'restoreDays' is provided, no attempt at updating other retention data will be made. To migrate to the new usage, issuing a request with restoreDays=10 would instead set the archiveDate's time stamp in the PUT body to 10 days in the future.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_conversation_id_recordings_recording_id(conversation_id, recording_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str recording_id: Recording ID (required)
        :param Recording body: recording (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'recording_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_conversation_id_recordings_recording_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `put_conversation_id_recordings_recording_id`")
        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `put_conversation_id_recordings_recording_id`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_conversation_id_recordings_recording_id`")

        resource_path = '/api/v2/conversations/{conversationId}/recordings/{recordingId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_conversation_id_recordings_recording_id_annotations_annotation_id(self, conversation_id, recording_id, annotation_id, **kwargs):
        """
        Update annotation
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_conversation_id_recordings_recording_id_annotations_annotation_id(conversation_id, recording_id, annotation_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str conversation_id: Conversation ID (required)
        :param str recording_id: Recording ID (required)
        :param str annotation_id: Annotation ID (required)
        :param Annotation body: annotation
        :return: Annotation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['conversation_id', 'recording_id', 'annotation_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_conversation_id_recordings_recording_id_annotations_annotation_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'conversation_id' is set
        if ('conversation_id' not in params) or (params['conversation_id'] is None):
            raise ValueError("Missing the required parameter `conversation_id` when calling `put_conversation_id_recordings_recording_id_annotations_annotation_id`")
        # verify the required parameter 'recording_id' is set
        if ('recording_id' not in params) or (params['recording_id'] is None):
            raise ValueError("Missing the required parameter `recording_id` when calling `put_conversation_id_recordings_recording_id_annotations_annotation_id`")
        # verify the required parameter 'annotation_id' is set
        if ('annotation_id' not in params) or (params['annotation_id'] is None):
            raise ValueError("Missing the required parameter `annotation_id` when calling `put_conversation_id_recordings_recording_id_annotations_annotation_id`")

        resource_path = '/api/v2/conversations/{conversationId}/recordings/{recordingId}/annotations/{annotationId}'.replace('{format}', 'json')
        path_params = {}
        if 'conversation_id' in params:
            path_params['conversationId'] = params['conversation_id']
        if 'recording_id' in params:
            path_params['recordingId'] = params['recording_id']
        if 'annotation_id' in params:
            path_params['annotationId'] = params['annotation_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Annotation',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_mediaretentionpolicies_policy_id(self, policy_id, **kwargs):
        """
        Update a media retention policy
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_mediaretentionpolicies_policy_id(policy_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str policy_id: Policy ID (required)
        :param Policy body: Policy
        :return: Policy
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_mediaretentionpolicies_policy_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'policy_id' is set
        if ('policy_id' not in params) or (params['policy_id'] is None):
            raise ValueError("Missing the required parameter `policy_id` when calling `put_mediaretentionpolicies_policy_id`")

        resource_path = '/api/v2/recording/mediaretentionpolicies/{policyId}'.replace('{format}', 'json')
        path_params = {}
        if 'policy_id' in params:
            path_params['policyId'] = params['policy_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Policy',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_settings(self, **kwargs):
        """
        Update the Recording Settings for the Organization
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_settings(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param RecordingSettings body: 
        :return: RecordingSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_settings" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/recording/settings'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='RecordingSettings',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
